# --8<--8<--8<--8<--
#
# Copyright (C) 2007 Smithsonian Astrophysical Observatory
#
# This file is part of mst-cpan
#
# mst-cpan is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# mst-cpan is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the 
#       Free Software Foundation, Inc. 
#       51 Franklin Street, Fifth Floor
#       Boston, MA  02110-1301, USA
#
# -->8-->8-->8-->8--

package MST::CPAN::Handler::PGPLOT;

use strict;
use warnings;


use base 'MST::CPAN::Handler';

use CPAN qw();
use Config;

use File::Copy;

sub install
{
    my ( $self ) = @_;

    $self->require('ExtUtils::PkgConfig');
    $self->require('ExtUtils::F77');

    my $libdirs;
    my $incdirs;
    my $XDIR;

    my $package = 
      exists $::opt{ccversion}
        ? "pgplot-$::opt{ccversion}"
	: 'pgplot';

    my @libdirs = map { s/^-L//; $_ } grep { /^-L/ }
      split(' ', ExtUtils::PkgConfig->libs_only_L( "$package-c" ) );

    $libdirs = join(',', @libdirs );


    my @incdirs =  map { s/^-I//; $_ } grep { /^-I/ }
      split(' ', ExtUtils::PkgConfig->cflags( "$package-c" ) );

    $incdirs = join(',', @incdirs );


    if ( $::opt{SysArch}{os_type} eq 'solaris' )
    {
	$self->fix_MakefilePL
	  ( 'qw/ pgplot cpgplot /' => "qw/ $package c$package /",
	    '"-L$_"' => '"-R$_ -L$_"'
	  );
    }

    # work around braindead redhat Perl mods
    if ( $::opt{SysArch}{os_vendor} eq 'RHFC' )
    {
	$self->fix_MakefilePL
	  ( 'WriteMakefile(' => 
	    "WriteMakefile(\n\tUSE_MM_LD_RUN_PATH=>1,"
	  );

	$XDIR = '/usr/X11R6/lib64'
	  if -e '/usr/X11R6/lib64';
    }

    my $makepl_arg = 
      exists $CPAN::Config->{makepl_arg} ? $CPAN::Config->{makepl_arg} : '';

    $makepl_arg = join( ' ', 
			$makepl_arg, 
			"LDIR=$libdirs",
			"IDIR=$incdirs",
			"EXLIB=png,z",
			( $XDIR ? "XDIR=$XDIR" : () ),
		      );

    local $CPAN::Config->{makepl_arg} = $makepl_arg;

    print STDERR "$makepl_arg\n";

    $self->SUPER::install( );
}


1;
